@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2020 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2021 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -8,9 +8,10 @@
 from __future__ import annotations
 
 import sys
-from typing import Dict, List, Tuple, cast
+from typing import Dict, List, Optional, Tuple, cast
 
 from bytecode import Bytecode, ControlFlowGraph
+from networkx import NetworkXError, diameter
 
 import pynguin.analyses.controlflow.programgraph as pg
 
@@ -29,6 +30,7 @@ class CFG(pg.ProgramGraph[pg.ProgramGraphNode]):
         """
         super().__init__()
         self._bytecode_cfg = bytecode_cfg
+        self._diameter: Optional[int] = None
 
     @staticmethod
     def from_bytecode(bytecode: Bytecode) -> CFG:
@@ -208,3 +210,22 @@ class CFG(pg.ProgramGraph[pg.ProgramGraphNode]):
             McCabe's cyclocmatic complexity number
         """
         return len(self._graph.edges) - len(self._graph.nodes) + 2
+
+    @property
+    def diameter(self) -> int:
+        """Computes the diameter of the graph
+
+        Returns:
+            The diameter of the graph
+        """
+        if self._diameter is None:
+            # Do this computation lazily
+            try:
+                self._diameter = diameter(self._graph, usebounds=True)
+            except NetworkXError:
+                # It seems like NetworkX makes some assumptions on the graph which
+                # are not documented (or which I could not find at least) that caused
+                # these errors.
+                # If the diameter computation fails for some reason, use an upper bound
+                self._diameter = len(self._graph.edges)
+        return self._diameter
