@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2020 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2021 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -25,6 +25,7 @@ class ProgramGraphNode:
         self._index = index
         self._basic_block = basic_block
         self._is_artificial = is_artificial
+        self._predicate_id: Optional[int] = None
 
     @property
     def index(self) -> int:
@@ -53,6 +54,25 @@ class ProgramGraphNode:
         """
         return self._is_artificial
 
+    @property
+    def predicate_id(self) -> Optional[int]:
+        """If this node creates a branch based on a predicate, than this stores the id
+        of this predicate.
+
+        Returns:
+            The predicate id assigned to this node, if any.
+        """
+        return self._predicate_id
+
+    @predicate_id.setter
+    def predicate_id(self, predicate_id: int) -> None:
+        """Set a new predicate id.
+
+        Args:
+            predicate_id: The predicate id
+        """
+        self._predicate_id = predicate_id
+
     def __eq__(self, other: Any) -> bool:
         if not isinstance(other, ProgramGraphNode):
             return False
@@ -211,7 +231,8 @@ class ProgramGraph(Generic[N]):
         """
         return lowest_common_ancestor(self._graph, first, second)
 
-    def to_dot(self) -> str:
+    @property
+    def dot(self) -> str:
         """Provides the DOT representation of this graph.
 
         Returns:
